from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXStartCallAction(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXStartCallAction.isVideo)
        self.assertArgIsBOOL(CallKit.CXStartCallAction.setVideo_, 0)



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXHandle(TestCase):
    def test_constants(self):
        self.assertEqual(CallKit.CXHandleTypeGeneric, 1)
        self.assertEqual(CallKit.CXHandleTypePhoneNumber, 2)
        self.assertEqual(CallKit.CXHandleTypeEmailAddress, 3)

    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXHandle.isEqualToHandle_)



from PyObjCTools.TestSupport import TestCase
import CallKit  # noqa: F401
import objc


class TestCXCallObserver(TestCase):
    def test_protocols(self):
        objc.protocolNamed("CXCallObserverDelegate")



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXCall(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXCall.isOutgoing)
        self.assertResultIsBOOL(CallKit.CXCall.isOnHold)
        self.assertResultIsBOOL(CallKit.CXCall.hasConnected)
        self.assertResultIsBOOL(CallKit.CXCall.hasEnded)



from PyObjCTools.TestSupport import TestCase
import CallKit
import objc


class TestCXProvider(TestCase):
    def test_constants(self):
        self.assertEqual(CallKit.CXCallEndedReasonFailed, 1)
        self.assertEqual(CallKit.CXCallEndedReasonRemoteEnded, 2)
        self.assertEqual(CallKit.CXCallEndedReasonUnanswered, 3)
        self.assertEqual(CallKit.CXCallEndedReasonAnsweredElsewhere, 4)
        self.assertEqual(CallKit.CXCallEndedReasonDeclinedElsewhere, 5)

    def test_protocols(self):
        objc.protocolNamed("CXProviderDelegate")

    def test_methods(self):
        self.assertArgIsBlock(
            CallKit.CXProvider.reportNewIncomingCallWithUUID_update_completion_,
            2,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXCallController(TestCase):
    def test_methods(self):
        self.assertArgIsBlock(
            CallKit.CXCallController.requestTransaction_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            CallKit.CXCallController.requestTransactionWithActions_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            CallKit.CXCallController.requestTransactionWithAction_completion_, 1, b"v@"
        )



# This file is generated by objective.metadata
#
# Last update: Sat Jul 31 12:37:17 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$CXErrorDomain$CXErrorDomainCallDirectoryManager$CXErrorDomainIncomingCall$CXErrorDomainNotificationServiceExtension$CXErrorDomainRequestTransaction$"""
enums = """$CXCallDirectoryEnabledStatusDisabled@1$CXCallDirectoryEnabledStatusEnabled@2$CXCallDirectoryEnabledStatusUnknown@0$CXCallDirectoryPhoneNumberMax@9223372036854775806$CXCallEndedReasonAnsweredElsewhere@4$CXCallEndedReasonDeclinedElsewhere@5$CXCallEndedReasonFailed@1$CXCallEndedReasonRemoteEnded@2$CXCallEndedReasonUnanswered@3$CXErrorCodeCallDirectoryManagerErrorCurrentlyLoading@7$CXErrorCodeCallDirectoryManagerErrorDuplicateEntries@4$CXErrorCodeCallDirectoryManagerErrorEntriesOutOfOrder@3$CXErrorCodeCallDirectoryManagerErrorExtensionDisabled@6$CXErrorCodeCallDirectoryManagerErrorLoadingInterrupted@2$CXErrorCodeCallDirectoryManagerErrorMaximumEntriesExceeded@5$CXErrorCodeCallDirectoryManagerErrorNoExtensionFound@1$CXErrorCodeCallDirectoryManagerErrorUnexpectedIncrementalRemoval@8$CXErrorCodeCallDirectoryManagerErrorUnknown@0$CXErrorCodeIncomingCallErrorCallUUIDAlreadyExists@2$CXErrorCodeIncomingCallErrorFilteredByBlockList@4$CXErrorCodeIncomingCallErrorFilteredByDoNotDisturb@3$CXErrorCodeIncomingCallErrorUnentitled@1$CXErrorCodeIncomingCallErrorUnknown@0$CXErrorCodeInvalidArgument@2$CXErrorCodeMissingVoIPBackgroundMode@3$CXErrorCodeNotificationServiceExtensionErrorInvalidClientProcess@1$CXErrorCodeNotificationServiceExtensionErrorMissingNotificationFilteringEntitlement@2$CXErrorCodeNotificationServiceExtensionErrorUnknown@0$CXErrorCodeRequestTransactionErrorCallUUIDAlreadyExists@5$CXErrorCodeRequestTransactionErrorEmptyTransaction@3$CXErrorCodeRequestTransactionErrorInvalidAction@6$CXErrorCodeRequestTransactionErrorMaximumCallGroupsReached@7$CXErrorCodeRequestTransactionErrorUnentitled@1$CXErrorCodeRequestTransactionErrorUnknown@0$CXErrorCodeRequestTransactionErrorUnknownCallProvider@2$CXErrorCodeRequestTransactionErrorUnknownCallUUID@4$CXErrorCodeUnentitled@1$CXErrorCodeUnknownError@0$CXHandleTypeEmailAddress@3$CXHandleTypeGeneric@1$CXHandleTypePhoneNumber@2$CXPlayDTMFCallActionTypeHardPause@3$CXPlayDTMFCallActionTypeSingleTone@1$CXPlayDTMFCallActionTypeSoftPause@2$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"CXAction", b"isComplete", {"retval": {"type": b"Z"}})
    r(b"CXCall", b"hasConnected", {"retval": {"type": b"Z"}})
    r(b"CXCall", b"hasEnded", {"retval": {"type": b"Z"}})
    r(b"CXCall", b"isEqualToCall:", {"retval": {"type": b"Z"}})
    r(b"CXCall", b"isOnHold", {"retval": {"type": b"Z"}})
    r(b"CXCall", b"isOutgoing", {"retval": {"type": b"Z"}})
    r(
        b"CXCallController",
        b"requestTransaction:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CXCallController",
        b"requestTransactionWithAction:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CXCallController",
        b"requestTransactionWithActions:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CXCallDirectoryExtensionContext",
        b"completeRequestReturningItems:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    }
                }
            }
        },
    )
    r(
        b"CXCallDirectoryExtensionContext",
        b"completeRequestWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"Z"}},
                    }
                }
            }
        },
    )
    r(b"CXCallDirectoryExtensionContext", b"isIncremental", {"retval": {"type": b"Z"}})
    r(
        b"CXCallDirectoryManager",
        b"getEnabledStatusForExtensionWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"q"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"CXCallDirectoryManager",
        b"openSettingsWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CXCallDirectoryManager",
        b"reloadExtensionWithIdentifier:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"CXCallUpdate", b"hasVideo", {"retval": {"type": b"Z"}})
    r(b"CXCallUpdate", b"setHasVideo:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXCallUpdate", b"setSupportsDTMF:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXCallUpdate", b"setSupportsGrouping:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXCallUpdate", b"setSupportsHolding:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXCallUpdate", b"setSupportsUngrouping:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXCallUpdate", b"supportsDTMF", {"retval": {"type": b"Z"}})
    r(b"CXCallUpdate", b"supportsGrouping", {"retval": {"type": b"Z"}})
    r(b"CXCallUpdate", b"supportsHolding", {"retval": {"type": b"Z"}})
    r(b"CXCallUpdate", b"supportsUngrouping", {"retval": {"type": b"Z"}})
    r(b"CXHandle", b"isEqualToHandle:", {"retval": {"type": b"Z"}})
    r(
        b"CXProvider",
        b"reportNewIncomingCallWithUUID:update:completion:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"CXProvider",
        b"reportNewIncomingVoIPPushPayload:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(b"CXProviderConfiguration", b"includesCallsInRecents", {"retval": {"type": b"Z"}})
    r(
        b"CXProviderConfiguration",
        b"setIncludesCallsInRecents:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"CXProviderConfiguration",
        b"setSupportsVideo:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CXProviderConfiguration", b"supportsVideo", {"retval": {"type": b"Z"}})
    r(
        b"CXSetHeldCallAction",
        b"initWithCallUUID:onHold:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(b"CXSetHeldCallAction", b"isOnHold", {"retval": {"type": b"Z"}})
    r(b"CXSetHeldCallAction", b"setOnHold:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"CXSetMutedCallAction",
        b"initWithCallUUID:muted:",
        {"arguments": {3: {"type": b"Z"}}},
    )
    r(b"CXSetMutedCallAction", b"isMuted", {"retval": {"type": b"Z"}})
    r(b"CXSetMutedCallAction", b"setMuted:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXStartCallAction", b"isVideo", {"retval": {"type": b"Z"}})
    r(b"CXStartCallAction", b"setVideo:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CXTransaction", b"isComplete", {"retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"callObserver:callChanged:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:didActivateAudioSession:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:didDeactivateAudioSession:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:executeTransaction:",
        {
            "required": False,
            "retval": {"type": b"Z"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performAnswerCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performEndCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performPlayDTMFCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performSetGroupCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performSetHeldCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performSetMutedCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:performStartCallAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"provider:timedOutPerformingAction:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"providerDidBegin:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"providerDidReset:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"requestFailedForExtensionContext:withError:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXSetHeldCallAction(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXSetHeldCallAction.isOnHold)
        self.assertArgIsBOOL(CallKit.CXSetHeldCallAction.setOnHold_, 0)



from PyObjCTools.TestSupport import TestCase
import CallKit
import sys


class TestCXCallDirectory(TestCase):
    def test_constants(self):
        self.assertEqual(CallKit.CXCallDirectoryPhoneNumberMax, sys.maxsize - 1)



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXCallUpdate(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXCallUpdate.supportsHolding)
        self.assertArgIsBOOL(CallKit.CXCallUpdate.setSupportsHolding_, 0)
        self.assertResultIsBOOL(CallKit.CXCallUpdate.supportsGrouping)
        self.assertArgIsBOOL(CallKit.CXCallUpdate.setSupportsGrouping_, 0)
        self.assertResultIsBOOL(CallKit.CXCallUpdate.supportsUngrouping)
        self.assertArgIsBOOL(CallKit.CXCallUpdate.setSupportsUngrouping_, 0)
        self.assertResultIsBOOL(CallKit.CXCallUpdate.supportsDTMF)
        self.assertArgIsBOOL(CallKit.CXCallUpdate.setSupportsDTMF_, 0)
        self.assertResultIsBOOL(CallKit.CXCallUpdate.hasVideo)
        self.assertArgIsBOOL(CallKit.CXCallUpdate.setHasVideo_, 0)



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXSetMutedCallAction(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXSetMutedCallAction.isMuted)
        self.assertArgIsBOOL(CallKit.CXSetMutedCallAction.setMuted_, 0)



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXProviderConfiguration(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(CallKit.CXProviderConfiguration.includesCallsInRecents)
        self.assertArgIsBOOL(
            CallKit.CXProviderConfiguration.setIncludesCallsInRecents_, 0
        )
        self.assertResultIsBOOL(CallKit.CXProviderConfiguration.supportsVideo)
        self.assertArgIsBOOL(CallKit.CXProviderConfiguration.setSupportsVideo_, 0)



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXPlayDTMFCallAction(TestCase):
    def test_constants(self):
        self.assertEqual(CallKit.CXPlayDTMFCallActionTypeSingleTone, 1)
        self.assertEqual(CallKit.CXPlayDTMFCallActionTypeSoftPause, 2)
        self.assertEqual(CallKit.CXPlayDTMFCallActionTypeHardPause, 3)



from PyObjCTools.TestSupport import TestCase
import CallKit


class TestCXError(TestCase):
    def test_constants(self):
        self.assertIsInstance(CallKit.CXErrorDomain, str)
        self.assertIsInstance(CallKit.CXErrorDomainIncomingCall, str)
        self.assertIsInstance(CallKit.CXErrorDomainRequestTransaction, str)
        self.assertIsInstance(CallKit.CXErrorDomainCallDirectoryManager, str)

        self.assertEqual(CallKit.CXErrorCodeUnknownError, 0)
        self.assertEqual(CallKit.CXErrorCodeUnentitled, 1)
        self.assertEqual(CallKit.CXErrorCodeInvalidArgument, 2)

        self.assertEqual(CallKit.CXErrorCodeIncomingCallErrorUnknown, 0)
        self.assertEqual(CallKit.CXErrorCodeIncomingCallErrorUnentitled, 1)
        self.assertEqual(CallKit.CXErrorCodeIncomingCallErrorCallUUIDAlreadyExists, 2)
        self.assertEqual(CallKit.CXErrorCodeIncomingCallErrorFilteredByDoNotDisturb, 3)
        self.assertEqual(CallKit.CXErrorCodeIncomingCallErrorFilteredByBlockList, 4)

        self.assertEqual(CallKit.CXErrorCodeRequestTransactionErrorUnknown, 0)
        self.assertEqual(CallKit.CXErrorCodeRequestTransactionErrorUnentitled, 1)
        self.assertEqual(
            CallKit.CXErrorCodeRequestTransactionErrorUnknownCallProvider, 2
        )
        self.assertEqual(CallKit.CXErrorCodeRequestTransactionErrorEmptyTransaction, 3)
        self.assertEqual(CallKit.CXErrorCodeRequestTransactionErrorUnknownCallUUID, 4)
        self.assertEqual(
            CallKit.CXErrorCodeRequestTransactionErrorCallUUIDAlreadyExists, 5
        )
        self.assertEqual(CallKit.CXErrorCodeRequestTransactionErrorInvalidAction, 6)
        self.assertEqual(
            CallKit.CXErrorCodeRequestTransactionErrorMaximumCallGroupsReached, 7
        )

        self.assertEqual(CallKit.CXErrorCodeCallDirectoryManagerErrorUnknown, 0)
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorNoExtensionFound, 1
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorLoadingInterrupted, 2
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorEntriesOutOfOrder, 3
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorDuplicateEntries, 4
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorMaximumEntriesExceeded, 5
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorExtensionDisabled, 6
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorCurrentlyLoading, 7
        )
        self.assertEqual(
            CallKit.CXErrorCodeCallDirectoryManagerErrorUnexpectedIncrementalRemoval, 8
        )
